start

# TBX

TBX is the LISA standard for terminology and term exchange.

For information on more file formats, see conformance.

## References

- Standard home page
- Specification
- ISO 30042 - TBX is an approved ISO standard

You might also be interested in reading about TBX-Basic - a simpler, reduced version of TBX with most of the useful features included.

## Standard conformance

### Done

- Basic file creation
- Creating a bilingual list from CSV with csv2tbx
- Using <tig> tags, not ntig

### Todo

- id attributes for termEntry tags
- ntig, read and write
- multiple languages
- synonyms
- cross references
- abbreviations
- definitions
- context
- parts of speech

## Implementation notes for missing features

Note here:

- NLS - South African National Language Services - Multilingual Maths Dictionary

### Synonyms

NLS: Extra listing
TBX:

    <termNote type="termNote">synonym</termNote>

according to this TBX documentation. In another place:

    <termNote type="termType">synonym</termNote>

inside a <termGrp>, following <term>

### Definition

NLS: term {definition/contextual information}
TBX

    <descripGrp>
       <descrip type="definition">The longish definition of the term</descrip>
    </descripGrp>

inside langSet <descript> can probably be used directly under langSet

### Context

NLS: term {definition/contextual information} (see above)
TBX:

    <descrip type="context">A usually somewhat longer contextual sentence.</descrip>

inside <ntig>

### Parts of speech

NLS: term v. (or adj, or n.)
TBX:

    <termNote type="partOfSpeech" >noun</termNote>

following <term>

### Cross reference

NLS: alternate term → real lemma
TBX: <ref> TODO

### Abbreviations

NLS: same as alternate term: a.m. → before noon
TBX: TODO

## TBX cheat sheet

1. source word in English
2. definition in English
3. translation of source word to XX
4. definition in XX
5. comment
6. syntactic group
7. one or more tags
8. a reference number

    <termEntry id="4324 (8)">
        <note>tag1, tag2, tag3 (7) -
    (Actually not clear what the best mapping to TBX is in this case.)</note>
        <langSet xml:lang="en">
            <tig>
                <term>sound (1)</term>
                <termNote type="partOfSpeech">noun (6)</termNote>
            </tig>
            <descripGrp>
                <descrip type="definition">Something you can hear (2) -
    definition with an associated external source)</descrip>
                <xref type="xSource" target="http://www.something.org/?id=234">Glossmaster</xref>
            </descripGrp>
            <note>Any random note about the term. (5)
    (Actually there are ways of storing pretty specific stuff in specific spaces,
    but while it seems the comment could be a more verbose definition, examples,
    usage notes or anything else, we'll use this generic way.)
            </note>
        </langSet>
        <langSet xml:lang="af">
            <tig>
                <term>klank (3)</term>
            </tig>
            <descrip type="definition">Iets wat jy kan hoor (4) -
    definition without an external source)</descrip>
            <note>A note in the target language (5).</note>
        </langSet>
    </termEntry>

Note that the <xref> tags are optional (as are just about everything except termEntry, langSet and tig). They allow to link to an external source. An internal source can also be specified, or the definition can be specified without a source as shown for the term “klank”.